@@ -1,10 +1,10 @@
-from typing import Literal, Optional
+from typing import Any, Literal, Optional
 
 from . import models
 from .api import Endpoint, ep
 
 @ep("gen/welcome", models.Image)
-def generate_welcome(avatar: str, username: str, members: str, dev: any):
+def generate_welcome(avatar: str, username: str, members: str, dev: Any):
     ...
 
 @ep("gen/achievement", models.Image)
@@ -56,4 +56,4 @@ def nsfw(__name: __valid):
     return Endpoint(f"nsfw/{__name}", model=models.JSON, fn=lambda: None)
 
 def sfw(__name: __sfw_valid):
-    return Endpoint(f"sfw/{__name}", model=models.JSON, fn=lambda: None)
\ No newline at end of file
+    return Endpoint(f"sfw/{__name}", model=models.JSON, fn=lambda: None)
